# Diamond NAgg Map
A program for calculating the nitrogen aggragation state of diamonds from FTIR Spectra collected on a mapping microscope. Currently only supports maps from Thermo Fisher Nicolet FTIR microscopes and saved as a .MAP file. 

Notes about limiations and future work:
- The program currently only supports .MAP files from Thermo Fisher Nicolet FTIR microscopes.
- The program currently only supports the calculation of nitrogen aggregation states for Type IaA-B diamonds. I am working on adding support for Type Ib diamonds.
- I have a seperate program for calculating nitrogen in singla spectra files, but I have not yet integrated it into this program.
# 